@@ -5,8 +5,9 @@
 #' and output samples of randomly-resolved trees. As simple methods of time-scaling
 #' phylogenies of fossil taxa can have biasing effects on macroevolutionary analyses
 #' (Bapst, 2014, Paleobiology), this function is largely retained for legacy purposes
-#' and plotting applications. The functions listed here are \bold{not} realistic
-#' time-scaling methods!
+#' and plotting applications. The time-scaling methods implemented
+#' by the functions listed here do \bold{not} return realistic estimates of 
+#' divergence dates, users should investigate other time-scaling methods such as \code{\link{cal3TimePaleoPhy}}.
 #' 
 #' @details 
 #' \emph{Time-Scaling Methods}
@@ -185,7 +186,7 @@
 #' Ignored if type = "basic".
 
 #' @param ntrees Number of time-scaled trees to output. If ntrees is greater
-#' than one and both randres is false and dateTreatment is either
+#' than one and both randres is false and dateTreatment is neither
 #' 'minMax' or 'randObs', the function will fail and
 #' a warning is issued, as these arguments would simply produce multiple
 #' identical time-scaled trees.
@@ -322,12 +323,11 @@
 #' continuous-time ranges generated for time-scaling each tree. (Essentially a
 #' pseudo-timeData matrix.)
 
-# @note Please account for stratigraphic uncertainty in your analysis.
-# Unless you have exceptionally resolved data, use a wrapper with timePaleoPhy,
-# either the provided bin_timePaleoPhy or code a wrapper function of your
-# own that accounts for stratigraphic uncertainty in your dataset. Remember that
-# the FADs (earliest dates) given to timePaleoPhy will *always* be used to 
-# calibrate node ages!
+#' @note Please account for stratigraphic uncertainty in your analysis.
+#' Unless you have exceptionally resolved data, select an appropriate option in
+#' \code{dateTreatment} within \code{timePaleoPhy}, use the more sophisticated
+#' \code{bin_timePaleoPhy} or code your own wrapper function of \code{timePaleoPhy}
+#' that accounts for stratigraphic uncertainty in your dataset.
 
 #' @author David W. Bapst, heavily inspired by code supplied by Graeme Lloyd
 #' and Gene Hunt.
@@ -401,7 +401,9 @@
 #' ttrees <- timePaleoPhy(cladogram,rangesCont,type="basic",ntrees=9,randres=TRUE,
 #'     add.term=TRUE,plot=TRUE)
 #' #let's compare nine of them at once in a plot
-#' layout(matrix(1:9,3,3));parOrig <- par(mar=c(1,1,1,1))
+#' layout(matrix(1:9,3,3))
+#' parOrig <- par(no.readonly=TRUE)
+#' par(mar=c(1,1,1,1))
 #' for(i in 1:9){plot(ladderize(ttrees[[i]]),show.tip.label=FALSE,no.margin=TRUE)}
 #' #they are all a bit different!
 #' 
@@ -415,7 +417,9 @@
 #' multiDiv(ttrees)
 #' 
 #' #compare different methods of timePaleoPhy
-#' layout(matrix(1:6,3,2));parOrig <- par(mar=c(3,2,1,2))
+#' layout(matrix(1:6,3,2))
+#' parOrig <- par(no.readonly=TRUE)
+#' par(mar=c(3,2,1,2))
 #' plot(ladderize(timePaleoPhy(cladogram,rangesCont,type="basic",vartime=NULL,add.term=TRUE)))
 #'     axisPhylo();text(x=50,y=23,"type=basic",adj=c(0,0.5),cex=1.2)
 #' plot(ladderize(timePaleoPhy(cladogram,rangesCont,type="equal",vartime=10,add.term=TRUE)))
@@ -458,7 +462,7 @@
 #'     nonstoch.bin=TRUE,randres=TRUE,add.term=TRUE,plot=FALSE)
 #' phyloDiv(ttreeB3)
 #' 
-#' \dontrun{
+#' \donttest{
 #' #simple three taxon example for testing inc.term.adj
 #' ranges1<-cbind(c(3,4,5),c(2,3,1));rownames(ranges1)<-paste("t",1:3,sep="")
 #' clado1<-read.tree(file=NA,text="(t1,(t2,t3));")
@@ -669,7 +673,8 @@ timePaleoPhy<-function(tree,timeData,type="basic",vartime=NULL,ntrees=1,randres=
 			ttree$root.time<-latestAge+min(dist.nodes(ttree)[1:Ntip(ttree),Ntip(ttree)+1])	
 			}
 		if(plot){
-			parOrig<-par(mar=c(2.5,1,1,0.5));layout(1:2)
+			parOrig <- par(no.readonly=TRUE)
+			par(mar=c(2.5,1,1,0.5));layout(1:2)
 			plot(ladderize(tree),show.tip.label=TRUE,use.edge.length=FALSE)
 			plot(ladderize(ttree),show.tip.label=TRUE);axisPhylo()
 			layout(1);par(parOrig)
@@ -711,7 +716,7 @@ bin_timePaleoPhy<-function(tree,timeList,type="basic",vartime=NULL,ntrees=1,
 	if(ntrees==1 & !nonstoch.bin){
 		message("Warning: Do not interpret a single tree; dates are stochastically pulled from uniform distributions")}
 	if(ntrees<1){stop("Error: ntrees<1")}
-	if(dateTreatment=="minMax"){stop("Instead of dateTreatment='minMax', please use argument points.occur instead in bin functions")}
+	if(!is.null(sites) & point.occur){stop("Error: Inconsistent arguments, point.occur=TRUE would replace input 'sites' matrix\n Why not just make site assignments for first and last appearance the same in your input site matrix?")}
 	if(!any(dateTreatment==c("firstLast","randObs"))){
 		stop("dateTreatment must be one of 'firstLast' or 'randObs'!")}
 	#clean out all taxa which are NA or missing for timeData
@@ -742,7 +747,7 @@ bin_timePaleoPhy<-function(tree,timeList,type="basic",vartime=NULL,ntrees=1,
 				message(paste("Warning: Following taxa dropped from timeList:",paste0(notTree,collapse=", ")))}
 			timeList[[2]]<-timeList[[2]][!is.na(match(rownames(timeList[[2]]),tree$tip.label)),]
 		}else{
-			stop("Some taxa in timeList not included on tree: not automatic taxon drop if 'sites' are given. Please remove from both sites and timeList and try again.")
+			stop("Some taxa in timeList not included on tree: no automatic taxon drop if 'sites' are given. Please remove from both sites and timeList and try again.")
 			}
 		}	
 	timeList[[2]]<-timeList[[2]][!is.na(timeList[[2]][,1]),]
